; GIMP - The GNU Image Manipulation Program
; Copyright (C) 1995 Spencer Kimball and Peter Mattis
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
;
; Creates a Denim texture layer based on this tutorial:
; http://fence-post.deviantart.com/art/Creating-Denim-in-GIMP-53850678
; Script can be found under Filters > Render > Denim...
; The user sets the denim color.  The default setting is the color used in the tutorial



;Define Script

(define (fp-denim-script image drawable color)

;Declare Variables

    (let* 
    (
	(denimLayer 0)
	(patternLayer 0)
    )

(gimp-context-push)

; Begin Undo Group

(gimp-image-undo-group-start image)



; Set the foreground to the denim color

(gimp-context-set-foreground color)


; Create the denim layer, fill it with chosen color

(set! denimLayer (car (gimp-image-get-active-layer image)))
(gimp-edit-fill denimLayer FOREGROUND-FILL)
(plug-in-rgb-noise RUN-NONINTERACTIVE image denimLayer FALSE TRUE 0.2 0.2 0.2 0.0)

; Set scanline as the active pattern, add a transparent layer, and fill with scanline

(set! patternLayer (car (gimp-layer-copy denimLayer TRUE)))
(gimp-drawable-fill patternLayer TRANSPARENT-FILL)
(gimp-context-set-pattern "Diagscanline5")
(gimp-drawable-fill patternLayer PATTERN-FILL)
(gimp-image-add-layer image patternLayer -1)
(gimp-drawable-set-name patternLayer "Pattern Layer")
(gimp-edit-bucket-fill patternLayer PATTERN-BUCKET-FILL 0 100.0 255.0 TRUE 0 0)


; Use the patternLayer to bump map the denimLayer and add more noise to the denimLayer

(plug-in-bump-map RUN-NONINTERACTIVE image denimLayer patternLayer 135.0 45.0 3 0 0 255 0 TRUE TRUE 2)
(plug-in-rgb-noise RUN-NONINTERACTIVE image denimLayer FALSE TRUE 0.2 0.2 0.2 0.0)


; Remove the patternLayer

(gimp-image-remove-layer image patternLayer)

; Set the denimLayer as the active layer

(gimp-image-set-active-layer image denimLayer)


; End Undo Group

(gimp-image-undo-group-end image)

; Update display

(gimp-displays-flush)

; Resets previous user settings 

(gimp-context-pop)

)
)

; Register Script

(script-fu-register 	"fp-denim-script"
			"<Image>/Filters/Render/Denim..."
			"Create a Denim Fabric"
			"Art Wade"
			"Art Wade"
			"December 30, 2013"
			"RGB*"
			SF-IMAGE      "SF-IMAGE" 0
			SF-DRAWABLE   "SF-DRAWABLE" 0
			SF-COLOR      	"Denim Color" 		'(43 108 126)
)
				